/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import org.apache.tools.ant.Target;
import org.apache.tools.ant.Location;
import org.apache.tools.ant.Project;

/**
 * <p>
 * This class simply stores some data about the Ant project.
 * </p>
 *
 * <p>
 * It is passed with ant related data to ServerElement class instance and then to Server derived classes instances.
 * It is currently used to provide information to the Cactus testing back-end.
 * </p>
 *
 * <p>
 * Thread Safety : This class is immutable and so thread-safe.
 * </p>
 *
 * <p>
 * Note, this class is a data class and transfers ant related data internally.
 * </p>
 *
 * @author real_vg, TCSDEVELOPER
 * @version 1.0
 */
public class AntTaskInfo {

    /**
     * <p>
     * This variable represents the current Ant project.
     * It is initialized in constructor and never changed afterwards.
     * </p>
     *
     */
    private final Project project;

    /**
     * <p>
     * This variable represents the current Ant task name.
     * It is initialized in constructor and never changed afterwards.
     * </p>
     *
     */
    private final String taskName;

    /**
     * <p>
     * This variable represents the current Ant task location
     * It is initialized in constructor and never changed afterwards.
     * </p>
     *
     */
    private final Location location;

    /**
     * <p>
     * This variable represents the current Ant target being executed
     * It is initialized in constructor and never changed afterwards.
     * </p>
     *
     */
    private final Target target;

    /**
     * <p>
     * Creates an instance of class and initializes variables
     * with the values of like-named parameters.
     * </p>
     *
     * @param project the current Ant project
     * @param taskName the current Ant task name
     * @param location the current Ant task location
     * @param target the current Ant target being executed
     *
     * @throws IllegalArgumentException if any argument is null or taskName is empty
     */
    public AntTaskInfo(Project project, String taskName, Location location, Target target) {
        if (project == null) {
            throw new IllegalArgumentException("project is null.");
        }
        if (taskName == null) {
            throw new IllegalArgumentException("taskName is null.");
        }
        if (taskName.trim().length() == 0) {
            throw new IllegalArgumentException("taskName is empty.");
        }
        if (location == null) {
            throw new IllegalArgumentException("location is null.");
        }
        if (target == null) {
            throw new IllegalArgumentException("target is null.");
        }

        this.project = project;
        this.taskName = taskName;
        this.location = location;
        this.target = target;
    }

    /**
     * <p>
     * Returns the value of "project" variable which represents the current Ant project.
     * </p>
     *
     * @return the value of "project" variable
     */
    public Project getProject() {
        return this.project;
    }

    /**
     * <p>
     * Returns the value of "taskName" variable which represents the current Ant task name.
     * </p>
     *
     * @return the value of "taskName" variable
     */
    public String getTaskName() {
        return this.taskName;
    }

    /**
     * <p>
     * Returns the value of "location" variable which represents the current Ant task location.
     * </p>
     *
     * @return the value of "location" variable
     */
    public Location getLocation() {
        return this.location;
    }

    /**
     * <p>
     * Returns the value of "target" variable which represents the current Ant target being executed.
     * </p>
     *
     * @return the value of "target" variable
     */
    public Target getTarget() {
        return this.target;
    }
}
