/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import java.io.File;

/**
 * <p>
 * This class is derived from Server class and is the base class for all classes representing an application
 * server to be used while running tests.
 * Those classes will have corresponding elements in the Ant build file.
 * </p>
 *
 * <p>
 * Besides the attributes supported by Server class, here is the extra attributes supported by ApplicationServer class:
 * <ul>
 * <li>"warfile" - web application archive, implementation defines whether required or not</li>
 * <li>"earfile" - enterprise application archive, implementation defines whether required or not</li>
 * </ul>
 * </p>
 *
 * <p>
 * Note, "warfile" and "earfile" can not be specified together.
 * </p>
 *
 * <p>
 * Thread Safety : This class is mutable and so not thread-safe.
 * </p>
 *
 * @author real_vg, TCSDEVELOPER
 * @version 1.0
 */
public abstract class ApplicationServer extends Server {

    /**
     * <p>
     * This variable represents the "warfile" attribute.
     * </p>
     *
     * <p>
     * "warfile" attribute specifies the web application archive that should be tested.
     * The archive must already contain everything needed for running tests(cactified already).
     * Derived classes specify if this attribute is required.
     * </p>
     *
     * <p>
     * Initially is null, later can be set by the setWarFile() method.
     * </p>
     *
     * <p>
     * Note, can't be set together with the "earfile" attribute.
     * </p>
     */
    private File warFile;

    /**
     * <p>
     * This variable represents the "earfile" attribute.
     * </p>
     *
     * <p>
     * "earfile" attribute specifies the enterprise application archive that should be tested.
     * The archive must contain a web module that already contains everything needed for running tests
     * (cactified already).
     * Derived classes specify if this attribute is required.
     * </p>
     *
     * <p>
     * Initially is null, later can be set by the setEarFile() method.
     * </p>
     *
     * <p>
     * Note, can't be set together with "warfile" attribute.
     * </p>
     *
     */
    private File earFile;

    /**
     * <p>
     * Creates an instance of ApplicationServer class.
     * The type of server represented by the class is specified.
     * </p>
     *
     * <p>
     * Type can be a sting like "tomcat5x", which actually specifies the name and version of the server.
     * </p>
     *
     * @param type the type of the server
     *
     * @throws org.apache.tools.ant.BuildException if the type of the server is unrecognized, or any other error happens
     * @throws IllegalArgumentException if type is null or empty
     */
    protected ApplicationServer(String type) {
        super(type);
    }

    /**
     * <p>
     * Sets the value of the "warfile" attribute.
     * </p>
     *
     * <p>
     * "warfile" attribute specifies the web application archive that should be tested.
     * The archive must already contain everything needed for running tests(cactified already).
     * </p>
     *
     * <p>
     * Note, this method is intended to be called by ANT engine.
     * </p>
     *
     * @param warFile the value of the "warfile" attribute to be set
     */
    public void setWarFile(File warFile) {
        this.warFile = warFile;
    }

    /**
     * <p>
     * Returns the value of the "warfile" attribute.
     * </p>
     *
     * <p>
     * "warfile" attribute specifies the web application archive that should be tested.
     * The archive must already contain everything needed for running tests(cactified already).
     * </p>
     *
     * @return the value of the "warfile" attribute
     */
    public File getWarFile() {
        return this.warFile;
    }

    /**
     * <p>
     * Sets the value of the "earfile" attribute.
     * </p>
     *
     * <p>
     * "earfile" attribute specifies the enterprise application archive that should be tested.
     * The archive must contain a web module that already contains everything needed for running tests
     * (cactified already).
     * </p>
     *
     * <p>
     * Note, this method is intended to be called by ANT engine.
     * </p>
     *
     * @param earFile the value of the "earfile" attribute to be set
     */
    public void setEarFile(File earFile) {
        this.earFile = earFile;
    }

    /**
     * <p>
     * Returns the value of the "earfile" attribute.
     * </p>
     *
     * <p>
     * "earfile" attribute specifies the enterprise application archive that should be tested.
     * The archive must contain a web module that already contains everything needed for running tests
     * (cactified already).
     * </p>
     *
     * @return the value of the "earfile" attribute
     */
    public File getEarFile() {
        return this.earFile;
    }
}
