/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import java.io.File;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for ApplicationServer.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class ApplicationServerTests extends TestCase {
    /**
     * <p>
     * Type constant used for constructing ApplicationServer instance.
     * </p>
     */
    private static final String TYPE = "tomcat5x";

    /**
     * <p>
     * ApplicationServer instance for testing.
     * </p>
     */
    private ApplicationServer server;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     */
    protected void setUp() {
        server = new DummyApplicationServer(TYPE);
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        server = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(ApplicationServerTests.class);
    }

    /**
     * <p>
     * Tests ctor ApplicationServer#ApplicationServer(String) for accuracy.
     * Expects a new ApplicationServer instance created successfully.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create new ApplicationServer instance.", server);
    }

    /**
     * <p>
     * Tests ctor ApplicationServer#ApplicationServer(String) for failure.
     * It tests the case that when type is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_NullType() {
        try {
            new DummyApplicationServer(null);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor ApplicationServer#ApplicationServer(String) for failure.
     * It tests the case that when type is empty and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor1_EmptyType() {
        try {
            new DummyApplicationServer(" ");
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ApplicationServer#setWarFile(File) for accuracy.
     * Expects war file is correctly set.
     * </p>
     */
    public void testSetWarFile() {
        File warFile = new File("test_files/sample.war");
        server.setWarFile(warFile);

        assertEquals("Failed to get correct war file name.", "sample.war", server.getWarFile().getName());
    }

    /**
     * <p>
     * Tests ApplicationServer#getWarFile() for accuracy.
     * Expects the war file is initially null.
     * </p>
     */
    public void testGetWarFile() {
        assertNull("Expects null war file.", server.getWarFile());
    }

    /**
     * <p>
     * Tests ApplicationServer#setEarFile(File) for accuracy.
     * Expects ear file is correctly set.
     * </p>
     */
    public void testSetEarFile() {
        File earFile = new File("test_files/sample.ear");
        server.setEarFile(earFile);

        assertEquals("Failed to get correct ear file name.", "sample.ear", server.getEarFile().getName());
    }

    /**
     * <p>
     * Tests ApplicationServer#getEarFile() for accuracy.
     * Expects the ear file is initially null.
     * </p>
     */
    public void testGetEarFile() {
        assertNull("Expects null ear file.", server.getEarFile());
    }

    /**
     * <p>
     * This class extends ApplicationServer class.
     * It is used for testing propose.
     * </p>
     *
     * @author TCSDEVELOPER
     * @version 1.0
     */
    public static class DummyApplicationServer extends ApplicationServer {

        /**
         * <p>
         * Constructs a new DummyApplicationServer instance.
         * </p>
         *
         * @param type the type of the server
         * @throws IllegalArgumentException if type is null or empty
         */
        protected DummyApplicationServer(String type) {
            super(type);
        }

        /**
         * <p>
         * Not implemented.
         * </p>
         */
        public void startUp() {
            // do nothing, testing only.
        }

        /**
         * <p>
         * Not implemented.
         * </p>
         */
        public void shutDown() {
            // do nothing, testing only.
        }

        /**
         * <p>
         * Not implemented.
         * </p>
         */
        public void initData() {
            // do nothing, testing only.
        }

        /**
         * <p>
         * Not implemented.
         * </p>
         */
        public void cleanUpData() {
            // do nothing, testing only.
        }

    }

}