/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.web;

import java.io.File;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.FileSet;

import com.topcoder.testframework.TestHelper;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for PrepareTestEarTask.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */

public class PrepareTestEarTaskTests extends TestCase {
    /**
     * <p>
     * PrepareTestEarTask instance for testing.
     * </p>
     */
    private PrepareTestEarTask task;

    /**
     * <p>
     * Project instance used for integration unit testing PrepareTestEarTask.
     * </p>
     */
    private Project project;

    /**
     * <p>
     * Default Constructor.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public PrepareTestEarTaskTests() throws Exception {
        project = TestHelper.getProject("test_files/PrepareTestEarTask.xml");
    }

    /**
     * <p>
     * Setup test environment.
     * </p>
     * @throws Exception to JUnit
     *
     */
    protected void setUp() throws Exception {
        task = new PrepareTestEarTask();
        task.setProject(new Project());
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        task = null;

        TestHelper.clearTempFiles();
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(PrepareTestEarTaskTests.class);
    }

    /**
     * <p>
     * Tests ctor PrepareTestEarTask#PrepareTestEarTask() for accuracy.
     * Expects a new PrepareTestEarTask instance created successfully.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create new PrepareTestEarTask instance.", task);
    }

    /**
     * <p>
     * Tests PrepareTestEarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when srcFile and destFile are specified and expects executing successfully.
     * </p>
     *
     * <p>
     * The target to execute :
     * &lt;preparetestear srcFile=&quot;sample.ear&quot; destFile=&quot;temp/test1.ear&quot;/&gt;
     * </p>
     */
    public void testExecute1() {
        project.executeTarget("test1");
    }

    /**
     * <p>
     * Tests PrepareTestEarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when fileset element occurs and expects executing successfully.
     * </p>
     *
     * <p>
     * The target to execute:
     * &lt;preparetestear srcFile=&quot;sample.ear&quot; destFile=&quot;temp/test2.ear&quot;&gt;
     *     &lt;fileset dir=&quot;../conf&quot;/&gt;
     * &lt;/preparetestear&gt;
     * </p>
     */
    public void testExecute2() {
        project.executeTarget("test2");
    }

    /**
     * <p>
     * Tests PrepareTestEarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when srcFile attribute is missing and expects BuildException.
     * </p>
     *
     * <p>
     * The target to execute:
     * &lt;preparetestear destFile=&quot;temp/test2.ear&quot; /&gt;
     * </p>
     */
    public void testExecute3() {
        try {
            project.executeTarget("test3");
            fail("BuildException expected.");
        } catch (BuildException be) {
            //good
        }
    }

    /**
     * <p>
     * Tests PrepareTestEarTask#execute() for accuracy.
     * </p>
     *
     * <p>
     * It tests the case when destFile attribute is missing and expects BuildException.
     * </p>
     *
     * <p>
     * The target to execute:
     * &lt;preparetestear srcFile=&quot;sample.ear&quot; /&gt;
     * </p>
     */
    public void testExecute4() {
        try {
            project.executeTarget("test4");
            fail("BuildException expected.");
        } catch (BuildException be) {
            //good
        }
    }

    /**
     * <p>
     * Tests PrepareTestEarTask#setSrcFile(File) for accuracy.
     * Trivial Test because there's no way to get the result except integration test.
     * Please refer to all the execute() tests for thorough ones.
     * </p>
     */
    public void testSetSrcFile() {
        task.setSrcFile(new File("test_files/sample.ear"));
    }

    /**
     * <p>
     * Tests PrepareTestEarTask#setDestFile(File) for accuracy.
     * Trivial Test because there's no way to get the result except integration test.
     * Please refer to all the execute() tests for thorough ones.
     * </p>
     */
    public void testSetDestFile() {
        task.setSrcFile(new File("test_files/temp/test.ear"));
    }

    /**
     * <p>
     * Tests PrepareTestEarTask#addFileset(FileSet) for accuracy.
     * Trivial Test because there's no way to get the result except integration test.
     * Please refer to all the execute() tests for thorough ones.
     * </p>
     */
    public void testAddFileset() {
        FileSet fileSet = new FileSet();
        fileSet.setFile(new File("test_files/sample.jar"));

        task.addFileset(fileSet);
    }

}